function [S,I] = get_varsize(fname,var);
%function [S,I] = get_varsize(fname,var);
%This function returns the size of the variable in the netcdf file. It is
%usefully for automating the snc tools nc_varget where you need to know the
%size of the variable if you don't want to pull out the entire thing.
%
%   fname = name of the netcdf file
%   var = variable you want to get the size for, as a string (i.e. 'Ubar')
%   S - the size of that variable;
%   I - the full info about the variable.
%
%          Aaron Bever, May 2009


I = nc_getvarinfo(fname,var);
S = I.Size;
